aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/core/game_object.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/core/game_object.h')
-rw-r--r--engines/titanic/core/game_object.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/engines/titanic/core/game_object.h b/engines/titanic/core/game_object.h
index 9a7d426d0a..619c56bc50 100644
--- a/engines/titanic/core/game_object.h
+++ b/engines/titanic/core/game_object.h
@@ -611,10 +611,11 @@ public:
/**
* Returns a point that falls within the object. Used for simulating
* mouse clicks for movement when arrow keys are pressed
* @param pt Return point
* @returns True if a point was found
*/
- virtual bool findPoint(Point &pt);
+ bool findPoint(Quadrant quadrant, Point &pt);
/**
* Set the position of the object
@@ -611,10 +611,11 @@ public:
* Returns a point that falls within the object. Used for simulating
* mouse clicks for movement when arrow keys are pressed
- * @param pt Return point
- * @returns True if a point was found
+ * @param quadrant Quadrant (edge) to return point for
+ * @param pt Return point
+ * @returns True if a point was found
*/